# Introduction

This package is part of the Kadenze Academy program [Creative Applications of Deep Learning w/ TensorFlow](https://www.kadenze.com/programs/creative-applications-of-deep-learning-with-tensorflow).

# Contents 

This package contains various models, architectures, and building blocks covered in the Kadenze Academy program including:

* Autoencoders  
* Character Level Recurrent Neural Network (CharRNN)  
* Conditional Pixel CNN  
* CycleGAN  
* Deep Convolutional Generative Adversarial Networks (DCGAN)  
* Deep Dream  
* Deep Recurrent Attentive Writer (DRAW)  
* Gated Convolution  
* Generative Adversarial Networks (GAN)  
* Global Vector Embeddings (GloVe)  
* Illustration2Vec  
* Inception  
* Mixture Density Networks (MDN)  
* PixelCNN  
* NSynth  
* Residual Networks 
* Sequence2Seqeuence (Seq2Seq) w/ Attention (both bucketed and dynamic rnn variants available)  
* Style Net  
* Variational Autoencoders (VAE)  
* Variational Autoencoding Generative Adversarial Networks (VAEGAN)  
* Video Style Net  
* VGG16  
* WaveNet / Fast WaveNet Generation w/ Queues / WaveNet Autoencoder (NSynth)  
* Word2Vec  

and more.  It also includes various datasets, preprocessing, batch generators, input pipelines, and plenty more for datasets such as:

* CELEB  
* CIFAR  
* Cornell  
* MNIST  
* TedLium  
* LibriSpeech  
* VCTK  

and plenty of utilities for working with images, GIFs, sound (wave) files, MIDI, video, text, TensorFlow, TensorBoard, and their graphs.

Examples of each module's use can be found in the tests folder.

# Contributing

Contributions, such as other model architectures, bug fixes, dataset handling, etc... are welcome and should be filed on the GitHub.
